<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="103"/>
        <source>Actions:</source>
        <translation>Действия:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="122"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="226"/>
        <source>Clear All</source>
        <translation>Очистить все</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="234"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="241"/>
        <location filename="../notifyd.cpp" line="299"/>
        <location filename="../notifyd.cpp" line="319"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>%n непрочитанное уведомление</numerusform>
            <numerusform>%n непрочитанных уведомления</numerusform>
            <numerusform>%n непрочитанных уведомлений</numerusform>
        </translation>
    </message>
</context>
</TS>
